django-socialregistration
=========================

django-socialregistratin enables developers to add user registration
with OAuth, OAuth2 and OpenID services.

See `documentation <http://django-socialregistration.readthedocs.org/en/latest/>`_
for installation and configuration.
